@@ -2,32 +2,8 @@
 # Like what you see? Join us!
 # https://www.univention.com/about-us/careers/vacancies/
 #
-# Copyright 2004-2025 Univention GmbH
-#
-# https://www.univention.de/
-#
-# All rights reserved.
-#
-# The source code of this program is made available
-# under the terms of the GNU Affero General Public License version 3
-# (GNU AGPL V3) as published by the Free Software Foundation.
-#
-# Binary versions of this program provided by Univention to you as
-# well as other copyrighted, protected or trademarked materials like
-# Logos, graphics, fonts, specific documentations and configurations,
-# cryptographic keys etc. are subject to a license agreement between
-# you and Univention and not subject to the GNU AGPL V3.
-#
-# In the case you use this program under the terms of the GNU AGPL V3,
-# the program is provided in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU Affero General Public License for more details.
-#
-# You should have received a copy of the GNU Affero General Public
-# License with the Debian GNU/Linux or Univention distribution in file
-# /usr/share/common-licenses/AGPL-3; if not, see
-# <https://www.gnu.org/licenses/>.
+# SPDX-FileCopyrightText: 2004-2025 Univention GmbH
+# SPDX-License-Identifier: AGPL-3.0-only
 
 """|UDM| module for containers"""
 
@@ -56,6 +32,12 @@ options = {
         default=True,
         objectClasses=['top', 'organizationalRole'],
     ),
+    'group-settings': univention.admin.option(
+        short_description=_('Default Group Settings'),
+        objectClasses=['univentionContainerDefault'],
+        default=False,
+        editable=True,
+    ),
 }
 property_descriptions = {
     'name': univention.admin.property(
@@ -146,6 +128,54 @@ property_descriptions = {
         include_in_default_search=True,
         readonly_when_synced=True,
     ),
+    'defaultGroup': univention.admin.property(
+        short_description=_('Default Primary Group'),
+        long_description='',
+        syntax=univention.admin.syntax.GroupDNOrEmpty,
+        options=['group-settings'],
+        dontsearch=True,
+        required=False,
+    ),
+    'defaultComputerGroup': univention.admin.property(
+        short_description=_('Default Group for Computers'),
+        long_description='',
+        syntax=univention.admin.syntax.GroupDNOrEmpty,
+        options=['group-settings'],
+        dontsearch=True,
+        required=False,
+    ),
+    'defaultDomainControllerGroup': univention.admin.property(
+        short_description=_('Default Group for Replica Directory Nodes'),
+        long_description='',
+        syntax=univention.admin.syntax.GroupDNOrEmpty,
+        options=['group-settings'],
+        dontsearch=True,
+        required=False,
+    ),
+    'defaultDomainControllerMBGroup': univention.admin.property(
+        short_description=_('Default Group for Primary and Backup Directory Nodes'),
+        long_description='',
+        syntax=univention.admin.syntax.GroupDNOrEmpty,
+        options=['group-settings'],
+        dontsearch=True,
+        required=False,
+    ),
+    'defaultMemberServerGroup': univention.admin.property(
+        short_description=_('Default Group for Managed Nodes'),
+        long_description='',
+        syntax=univention.admin.syntax.GroupDNOrEmpty,
+        options=['group-settings'],
+        dontsearch=True,
+        required=False,
+    ),
+    'defaultClientGroup': univention.admin.property(
+        short_description=_('Default Group for Client Computers'),
+        long_description='',
+        syntax=univention.admin.syntax.GroupDNOrEmpty,
+        options=['group-settings'],
+        dontsearch=True,
+        required=False,
+    ),
 }
 
 layout = [
@@ -162,11 +192,27 @@ layout = [
             ["policyPath", "licensePath"],
         ]),
     ]),
+    Tab(_('Default Primary Groups'), _('Default Primary Groups'), layout=[
+        Group(_('Default Primary Groups'), layout=[
+            "defaultGroup",
+            "defaultComputerGroup",
+            "defaultDomainControllerMBGroup",
+            "defaultDomainControllerGroup",
+            "defaultMemberServerGroup",
+            "defaultClientGroup",
+        ]),
+    ]),
 ]
 
 mapping = univention.admin.mapping.mapping()
 mapping.register('name', 'cn', None, univention.admin.mapping.ListToString)
 mapping.register('description', 'description', None, univention.admin.mapping.ListToString)
+mapping.register('defaultGroup', 'univentionDefaultGroup', None, univention.admin.mapping.ListToString)
+mapping.register('defaultComputerGroup', 'univentionDefaultComputerGroup', None, univention.admin.mapping.ListToString)
+mapping.register('defaultDomainControllerMBGroup', 'univentionDefaultDomainControllerMasterGroup', None, univention.admin.mapping.ListToString)
+mapping.register('defaultDomainControllerGroup', 'univentionDefaultDomainControllerGroup', None, univention.admin.mapping.ListToString)
+mapping.register('defaultMemberServerGroup', 'univentionDefaultMemberserverGroup', None, univention.admin.mapping.ListToString)
+mapping.register('defaultClientGroup', 'univentionDefaultClientGroup', None, univention.admin.mapping.ListToString)
 
 
 class object(univention.admin.handlers.simpleLdap):
