@@ -2,32 +2,8 @@
 # Like what you see? Join us!
 # https://www.univention.com/about-us/careers/vacancies/
 #
-# Copyright 2018-2025 Univention GmbH
-#
-# https://www.univention.de/
-#
-# All rights reserved.
-#
-# The source code of this program is made available
-# under the terms of the GNU Affero General Public License version 3
-# (GNU AGPL V3) as published by the Free Software Foundation.
-#
-# Binary versions of this program provided by Univention to you as
-# well as other copyrighted, protected or trademarked materials like
-# Logos, graphics, fonts, specific documentations and configurations,
-# cryptographic keys etc. are subject to a license agreement between
-# you and Univention.
-#
-# In the case you use this program under the terms of the GNU AGPL V3,
-# the program is provided in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU Affero General Public License for more details.
-#
-# You should have received a copy of the GNU Affero General Public
-# License with the Debian GNU/Linux or Univention distribution in file
-# /usr/share/common-licenses/AGPL-3; if not, see
-# <https://www.gnu.org/licenses/>.
+# SPDX-FileCopyrightText: 2018-2025 Univention GmbH
+# SPDX-License-Identifier: AGPL-3.0-only
 
 r"""Module and object for all `computers/\*` UDM modules."""
 
@@ -88,8 +64,7 @@ class ComputersMemberModule(ComputersAllModule):
 
     def _get_default_object_positions(self) -> list[str]:
         ret = super()._get_default_object_positions()
-        if len(ret) == 4 and \
-                f'cn=computers,{self.connection.base}' in ret and \
+        if f'cn=computers,{self.connection.base}' in ret and \
                 f'cn=memberserver,cn=computers,{self.connection.base}' in ret and \
                 f'cn=dc,cn=computers,{self.connection.base}' in ret and \
                 self.connection.base in ret:
